@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "neil" "0.3.69"
+(define-package "neil" "20251217.857"
   "Companion for Babashka Neil."
-  '((emacs "27.1"))
+  '((emacs "29.4"))
   :url "https://github.com/babashka/neil"
-  :commit "fa793214d7820e6763108c942e9cf16e1cd2db96"
-  :revdesc "fa793214d782"
+  :commit "196e8f7933289902965fdc6da2d0227b80e06936"
+  :revdesc "196e8f793328"
   :keywords '("convenience" "tools")
   :authors '(("Ag Ibragimov" . "agzam.ibragimov@gmail.com"))
   :maintainers '(("Ag Ibragimov" . "agzam.ibragimov@gmail.com")))
